from .lingua_sdk import Client
from .lingua_sdk import Model

# SDK metadata
__version__ = "0.0.1"
__author__ = "Vector AI Engineering"
__credits__ = "Vector Institute"
